@@ -35,6 +35,7 @@
 #include <libgnomeui/gnome-messagebox.h>
 #include <libgnomeui/gnome-stock.h>
 #include <glade/glade-xml.h>
+#include <string.h> /* For strlen */
 
 #include "window.h"
 #include "search.h"
@@ -173,6 +174,8 @@ action_find (GeditReplaceDialog *dialog,
 	guint pos_found;
 	gint line_found, total_lines;
 
+	gedit_debug (DEBUG_SEARCH, "");
+
 	found = gedit_search_execute (start_pos, case_sensitive, search_text,
 				      &pos_found, &line_found, &total_lines, TRUE);
 
@@ -182,12 +185,11 @@ action_find (GeditReplaceDialog *dialog,
 		return;
 	}
 
-	gedit_flash_va (_("Text found at line :%i"),line_found);
 	gedit_view_set_window_position_from_lines (dialog->view, line_found, total_lines);
 	gedit_view_set_position	(dialog->view, pos_found);
 	gedit_view_set_selection (dialog->view,
-				  pos_found + 1,
-				  pos_found + 1 + strlen (search_text));
+				  pos_found,
+				  pos_found + strlen (search_text));
 	
 	gtk_radio_button_select (GTK_RADIO_BUTTON(dialog->position)->group, 1);
 }
@@ -199,6 +201,7 @@ action_replace (GeditReplaceDialog *dialog,
 		const gchar *replace_text,
 		gboolean case_sensitive)
 {
+	gedit_debug (DEBUG_SEARCH, "");
 
 	gedit_document_replace_text (dialog->view->doc,
 				     replace_text,
@@ -218,29 +221,40 @@ action_replace (GeditReplaceDialog *dialog,
 
 static void
 action_replace_all (GeditReplaceDialog *dialog,
-		    guint start_pos,
+		    gint start_pos,
 		    const gchar *search_text,
 		    const gchar *replace_text,
 		    gboolean case_sensitive)
 {
 	guchar *new_buffer = NULL;
+	gint cursor_position;
+	gint num_lines;
+	gint line;
 
+	gedit_debug (DEBUG_SEARCH, "");
+
+	start_pos -= strlen (search_text);
+	if (start_pos < 0)
+		start_pos = 0;
+
+	cursor_position = gedit_view_get_position (dialog->view);
+		
 	dialog->replacements = gedit_replace_all_execute (dialog->view,
 							  start_pos,
 							  search_text,
 							  replace_text,
 							  case_sensitive,
+							  &cursor_position,
 							  &new_buffer);
+
 	if (dialog->replacements > 0)
 	{
-		gedit_document_delete_text (dialog->view->doc, 0,
-					    gedit_document_get_buffer_length(dialog->view->doc),
-					    TRUE);
-		gedit_document_insert_text (dialog->view->doc, new_buffer, 0, TRUE);
-		/* FIXME : use replace, for undo . !*/ 
-		/*
-		  gedit_document_replace_text (view->doc, new_buffer, 0, gedit_document_get_buffer_length(view->doc), TRUE);
-		*/
+		gedit_document_replace_text (dialog->view->doc, new_buffer,
+					     gedit_document_get_buffer_length (dialog->view->doc),
+					     0, TRUE);
+		line = gedit_search_pos_to_line (cursor_position, &num_lines);
+		gedit_view_set_window_position_from_lines (dialog->view, line, num_lines);
+		gedit_view_set_position (dialog->view, cursor_position);
 	} else
 		dialog->done = TRUE;
 
@@ -273,7 +287,7 @@ dialog_action (GeditReplaceDialog *dialog, gint button, gboolean replace)
 		return;
 	}
 	
-	/* Get the initial position */
+	/* Get the initial position, selected = start of doc, !selected = current pos */
 	selected = gtk_radio_group_get_selected (GTK_RADIO_BUTTON(dialog->position)->group);
 	switch (selected) {
 	case 0:
@@ -313,6 +327,8 @@ search_not_found_notify (GeditView * view)
 	GtkWidget *gnome_dialog;
 	gchar * msg;
 	
+	gedit_debug (DEBUG_SEARCH, "");
+
 	gedit_flash_va (_("Text not found"));
 
 	if (gedit_view_get_selection (view, NULL, NULL))
@@ -334,6 +350,9 @@ static void
 dialog_display_messages (GeditReplaceDialog *dialog)
 {
 	gchar *msg;
+
+	gedit_debug (DEBUG_SEARCH, "");
+	
 	/* This is done like this, since we need to close the other
 	   dialog before poping this dialogs*/
 	if (dialog->not_found || dialog->replacements == 0)
@@ -350,8 +369,12 @@ dialog_display_messages (GeditReplaceDialog *dialog)
 		g_free (msg);
 	}
 	if (dialog->replacements == -1) {
+#if 0 /* warning: too many arguments for format */
 		msg = g_strdup_printf (_("Could not allocate the memory for the Replace all request."),
 				       dialog->replacements);
+#endif
+		msg = g_strdup_printf (_("Could not allocate the memory for the Replace all request."));
+
 		gnome_dialog_run_and_close ((GnomeDialog *)
 					    gnome_message_box_new (msg,
 								   GNOME_MESSAGE_BOX_INFO,
@@ -416,6 +439,8 @@ gedit_find_again (void)
 {
 	GeditReplaceDialog *dialog;
 	const gchar *search_text;
+
+	gedit_debug (DEBUG_SEARCH, "");
 	
 	dialog = get_dialog ();
 
