@@ -141,8 +141,8 @@ gedit_search_start (void)
 		return;
 	}
 	
-	search_info.length = gedit_document_get_buffer_length (search_info.view->doc);
 	search_info.buffer = gedit_document_get_buffer (search_info.view->doc);
+	search_info.length = strlen (search_info.buffer);
 	search_info.state  = SEARCH_IN_PROGRESS_YES;
 }
 
@@ -428,9 +428,8 @@ gedit_file_info_cb (GtkWidget *widget, gpointer data)
 	
 }
 
-
-static gint
-pos_to_line (guint pos, gint *numlines)
+gint
+gedit_search_pos_to_line (guint pos, gint *numlines)
 {
 	gint lines = 1;
 	gint current_line = 0;
@@ -509,9 +508,9 @@ gedit_search_execute ( guint starting_position,
 		return FALSE;
 
 	if (return_the_line_number)
-		*line_found = pos_to_line ( p2, total_lines);
+		*line_found = gedit_search_pos_to_line ( p2, total_lines);
 
-	*pos_found = p2 - text_length;
+	*pos_found = p2 - text_length + 1;
 
 	if (gedit_view_active() != search_info.view)
 		g_warning("View is not the same F:%s L:%i", __FILE__, __LINE__);
@@ -554,8 +553,12 @@ gedit_search_line_to_pos (gint line, gint *lines)
 
 #define GEDIT_EXTRA_REPLACEMENTS_ 4
 gint
-gedit_replace_all_execute (GeditView *view, guint start_pos, const guchar *search_text,
-			   const guchar *replace_text, gint case_sensitive,
+gedit_replace_all_execute (GeditView *view,
+			   gint start_pos,
+			   const guchar *search_text,
+			   const guchar *replace_text,
+			   gboolean case_sensitive,
+			   gint *cursor_position,
 			   guchar **buffer)
 {
 	guchar * buffer_in;
@@ -575,8 +578,9 @@ gedit_replace_all_execute (GeditView *view, guint start_pos, const guchar *searc
 	gint grow_factor = GEDIT_EXTRA_REPLACEMENTS_;
 
 	gedit_debug (DEBUG_RECENT, "");
-	
+
 	g_return_val_if_fail (search_info.state == SEARCH_IN_PROGRESS_YES, 0);
+	g_return_val_if_fail (start_pos > -1, 0);
 
 	search_text_length = strlen (search_text);
 	replace_text_length = strlen (replace_text);
@@ -594,9 +598,9 @@ gedit_replace_all_execute (GeditView *view, guint start_pos, const guchar *searc
 
 	delta = replace_text_length - search_text_length;
 	if (delta > 0)
-		buffer_out_length = buffer_in_length + (grow_factor) * delta;
+		buffer_out_length = buffer_in_length + 1 + (grow_factor) * delta ;
 	else
-		buffer_out_length = buffer_in_length;
+		buffer_out_length = buffer_in_length + 1;
 
 	buffer_out = g_malloc (buffer_out_length);
 
@@ -625,7 +629,10 @@ gedit_replace_all_execute (GeditView *view, guint start_pos, const guchar *searc
 	/* Do the actual replace all */
 	while (p1 < buffer_in_length)
 	{
-		if (p2 > buffer_out_length - (delta*2)) /* Allocate for at leas 2 more replacements */
+		if (p1 == *cursor_position)
+			*cursor_position = p2;
+		
+		if (p2 > buffer_out_length - (delta*2)) /* Allocate for at least 2 more replacements */
 		{
 			if (delta < 1) {
 				g_warning ("This should not happen.\n");
@@ -666,15 +673,15 @@ gedit_replace_all_execute (GeditView *view, guint start_pos, const guchar *searc
 
 	buffer_out [p2] = '\0';
 
-	if (p2 > buffer_out_length )
+	if (p2 >= buffer_out_length )
 	{
-		g_warning ("Error ...\n");
-		g_assert_not_reached();
+		g_warning ("Error. Replace all has written outside of the memory requested.\n"
+			   "P2:%i -  buffer_out_length:%i", p2, buffer_out_length);
 	}
 
 	*buffer = buffer_out;
 
-	g_warning ("Return ...\n");
+	gedit_debug (DEBUG_RECENT, "end");
 	
 	return replacements;
 }
